@@ -1,29 +1,15 @@
 /*
  * BluezQt - Asynchronous Bluez wrapper library
  *
- * Copyright (C) 2014 David Rosca <nowrep@gmail.com>
+ * SPDX-FileCopyrightText: 2014 David Rosca <nowrep@gmail.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
 
 #include "profileadaptor.h"
-#include "profile.h"
-#include "manager.h"
 #include "device.h"
+#include "manager.h"
+#include "profile.h"
 
 #include <QDBusMessage>
 #include <QDBusObjectPath>
@@ -31,7 +17,6 @@
 
 namespace BluezQt
 {
-
 ProfileAdaptor::ProfileAdaptor(Profile *parent, Manager *manager)
     : QDBusAbstractAdaptor(parent)
     , m_profile(parent)
@@ -73,3 +58,5 @@ void ProfileAdaptor::Release()
 }
 
 } // namespace BluezQt
+
+#include "moc_profileadaptor.cpp"
